<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Repository;

use Dedi\SyliusBlogPlugin\Entity\CommentInterface;
use Pagerfanta\Doctrine\ORM\QueryAdapter;
use Pagerfanta\Pagerfanta;
use Sylius\Bundle\ResourceBundle\Doctrine\ORM\EntityRepository;
use Sylius\Component\Core\Model\ChannelInterface;

class CommentRepository extends EntityRepository
{
    public function findByChannelAndSlugArticle(
        ChannelInterface $channel,
        string $slug,
        string $order = 'DESC',
        ?string $locale = null
    ): Pagerfanta {
        $queryBuilder = $this->createQueryBuilder('o')
            ->innerJoin('o.article', 'a')
            ->innerJoin('a.translations', 'translation', 'WITH', 'translation.locale = :locale')
            ->andWhere('translation.slug = :slug')
            ->andWhere('a.enabled = true')
            ->andWhere(':channel MEMBER OF a.channels')
            ->andWhere('o.status = :status_enable')
            ->addOrderBy('o.createdAt', $order)
            ->setParameter('channel', $channel)
            ->setParameter('slug', $slug)
            ->setParameter('status_enable', CommentInterface::STATUS_ACCEPTED)
            ->setParameter('locale', $locale ?? 'fr_FR')
        ;

        $adapter = new QueryAdapter($queryBuilder, false);

        return new Pagerfanta($adapter);
    }
}
